==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControlCore/src/com/clustercontrol/notify/action/GetNotifyListTableDefine.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Locale;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.notify.util.EjbConnectionManager;
import com.clustercontrol.notify.ejb.session.NotifyController;
import com.clustercontrol.util.Messages;

/**
 * ΰơ֥륯饹Ǥ
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class GetNotifyListTableDefine {

    /**
     * ΰΥơ֥֤ޤ
     * 
     * @return ΰơ֥
     */
    public static ArrayList get() {
        NotifyController notify = EjbConnectionManager.getConnectionManager()
                .getNotifyController();

        ArrayList tableDefine = null;
        try {
            tableDefine = notify.getNotifyListTableDefine(Locale.getDefault());
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// ʤξ硢顼ɽ
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return tableDefine;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControlCore/src/com/clustercontrol/notify/action/GetNotifyListTableDefine.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Locale;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.notify.util.EjbConnectionManager;
import com.clustercontrol.notify.ejb.session.NotifyController;
import com.clustercontrol.util.Messages;

/**
 * 通知一覧テーブル定義情報を取得するクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class GetNotifyListTableDefine {

    /**
     * 通知一覧のテーブル定義情報を返します。
     * 
     * @return 通知一覧テーブル定義情報
     */
    public static ArrayList get() {
        NotifyController notify = EjbConnectionManager.getConnectionManager()
                .getNotifyController();

        ArrayList tableDefine = null;
        try {
            tableDefine = notify.getNotifyListTableDefine(Locale.getDefault());
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return tableDefine;
    }
}
